@@ -9,7 +9,8 @@ use Capture::Tiny qw(capture);
 use File::Find::Rule;
 use Future::Utils qw(fmap);
 use Path::Class;
-use Config::Any;
+use Config::INI::Reader;
+use Config::INI::Writer;
 use IPC::Run;
 use Try::Tiny;
 
@@ -30,7 +31,7 @@ deal with git subrepositories.
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 PACKAGE VARS
 
@@ -64,7 +65,13 @@ Controlled by the C<MG_IGNORE_{STDOUT,STDERR}> environment variables.
 
 Number of processes to run in parallel. Defaults to 20.
 
-Controller by the C<MG_CONCURRENT_PROCESSES> environment variable.
+Controlled by the C<MG_CONCURRENT_PROCESSES> environment variable.
+
+=head3 skip_readonly
+
+Do nothing to repositories that have C<readonly = 1> set in C<.mgconfig>.
+
+Controlled by the C<MG_SKIP_READONLY> environment variable.
 
 =cut
 
@@ -73,6 +80,7 @@ our %BEHAVIOUR = (
     ignore_stdout       => !!$ENV{MG_IGNORE_STDOUT},
     ignore_stderr       => !!$ENV{MG_IGNORE_STDERR},
     concurrent          => $ENV{MG_CONCURRENT_PROCESSES} // 20,
+    skip_readonly       => !!$ENV{MG_SKIP_READONLY},
 );
 
 =head1 FUNCTIONS
@@ -124,24 +132,14 @@ sub all_repositories {
     my $pwd = shift // dir->absolute;
     my $mg_parent = mg_parent $pwd;
 
-    my $cfg = Config::Any->load_files({
-        files => [ mgconfig ],
-        use_ext => 0,
-        force_plugins => [
-            qw/Config::Any::INI/
-        ]
-    });
+    my $cfg = Config::INI::Reader->read_file($mg_parent->file(mgconfig));
 
-    my $repos = +{
-        map { %$_ } values %{ $cfg->[0] }
-    };
-
-    for (keys %$repos) {
-        $repos->{$_}->{dir} //= dir($_)->basename =~ s/\.git$//r;
-        $repos->{$_}->{url} //= $_;
+    for (keys %$cfg) {
+        $cfg->{$_}->{dir} //= dir($_)->basename =~ s/\.git$//r;
+        $cfg->{$_}->{url} //= $_;
     }
 
-    return $repos;
+    return $cfg;
 }
 
 =head2 each($command)
@@ -236,6 +234,9 @@ This is the exported name of C<each>
 sub _run_in_repo {
     my ($cmd, $repo, $config) = @_;
 
+    return Future->done( $config->{dir} => "Readonly" )
+        if $BEHAVIOUR{skip_readonly} and $config->{readonly};
+
     if (ref $cmd eq 'ARRAY') {
         App::Multigit::Repo->new(
             name => $repo,
@@ -300,18 +301,9 @@ sub init {
         $config{$url}->{dir} = $dir;
     }
 
-    {
-        my $config_filename = dir($workdir)->file(mgconfig);
-        open my $config_out, ">", $config_filename;
-
-        for my $remote (sort_by { m{/([^/]+)$} } keys %config) {
-            say $config_out "[$remote]";
-            for my $thing (sort keys %{ $config{$remote} }) {
-                say $config_out "$thing=${\ $config{$remote}->{$thing} }";
-            }
-            say $config_out "";
-        }
-    }
+    
+    my $config_filename = dir($workdir)->file(mgconfig);
+    Config::INI::Writer->write_file(\%config, $config_filename);
 }
 
 =head2 base_branch
